@@ -751,7 +751,10 @@ lattice.options <- function(...)
               ##par.strip.text = NULL,
               ##layout = NULL,
               skip = FALSE,
-              strip = strip.default),
+              strip = strip.default,
+              xscale.components = xscale.components.default,
+              yscale.components = yscale.components.default,
+              axis = axis.default),
 
          axis.padding = list(numeric = 0.07, factor = 0.6),
 
@@ -760,7 +763,6 @@ lattice.options <- function(...)
          ## value for numeric is multiplicative, while factor is
          ## additive
 
-
          skip.boundary.labels = 0.02,
 
          ## ticks too close to the limits will not be drawn unless
